;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "howm" "20251005.1120"
  "Wiki-like note-taking tool."
  '((cl-lib "0.5"))
  :url "https://kaorahi.github.io/howm/"
  :commit "d1431c9e678de6e0c179b2a2bf405e8804472fee"
  :revdesc "d1431c9e678d"
  :authors '(("HIRAOKA Kazuyuki" . "kakkokakko@gmail.com"))
  :maintainers '(("HIRAOKA Kazuyuki" . "kakkokakko@gmail.com")))
